CTdata: The results of existing clinical trial data organized as a...

CTdataR Documentation

The results of existing clinical trial data organized as a data file, for use in Vignette 3

Description

The results of existing clinical trial data organized as a data file, for use in Vignette 3

Usage

data(CTdata)

Format

An object of class data.table (inherits from data.frame) with 56 rows and 7 columns.


rchendrickson/pmsimstats documentation built on Nov. 28, 2024, 11:05 a.m.