extracted_rp: Extracted response parameters for the vignette that...

extracted_rpR Documentation

Extracted response parameters for the vignette that reproduces the publication results.

Description

This contains a set of maximum, displacement, rate and standard deviation values that, when fed into the function modgompertz produces a combination of response factors (biologic response to the drug, br here or BR in the publication; expectancy related response, pb here or ER in the publication; and the non-treatment related time-varying factor, tv here or TR in the publication) that together could plausibly describe our existing RCT data set. This set of parameters was designed to make no other particular assumptions about how these factors would perform - to be a 'tabula rasa' parameter set - where e.g. the timecourse and maximum values of the expectancy related and tv/TR factors were assumed to be equal.

Usage

data(extracted_rp)

Format

An object of class data.table (inherits from data.frame) with 3 rows and 5 columns.


rchendrickson/pmsimstats documentation built on Nov. 28, 2024, 11:05 a.m.