View source: R/generateSimulatedResults.R
| generateSimulatedResults | R Documentation |
generateSimulatedResults rotates through a parameter space, creating
and analyizing simulated data and collating the results
generateSimulatedResults(
trialdesigns,
respparamsets,
blparamsets,
censorparams,
modelparams,
simparam,
analysisparams,
rawdataout = FALSE
)
trialdesigns |
A list of trial designs of the form generated by buildtrialdesigns |
respparamsets |
A list of options for |
blparamsets |
A list of options for |
censorparams |
A data.table where each row is a set of options for
|
modelparams |
A data.table where each row is a set of options for
|
simparam |
The options that control the logistics of the simulations:
|
analysisparams |
The options used by lme_analysis. Has the following components:
|
rawdataout=FALSE |
Binary - output the raw data for all simulations? This is memory intensive for large runs. |
This is a wrapper for generateData and lme_analysis that systematically works its way through a set of parameters and creates a specified number of repetitions of simulated data and results of analyizing that data for each set of parameter specifications.
Returns a list with three named parts:
results A large data table that tells you the parameters used
and the analysis results for every simulated trial, one row per simualated trial.
parameterselections A list desribing the parameterspace used.
This is important because some of the information in out$results is
the index of the parameter set selection, and you will need this additional
information to interpret it. For example, trialdesigns, respparamset,
blparamset, and modelparamset are all indexed.
rawdataout If you have rawdataout set to TRUE, you will
also get (1) drawdataout$precensor, a list of simulated trial data of
a length corresponding to the number of parameter permulations, with the order
parallel to that of the main output results. Repititions of a particular
parameter set are mixed, identified by irep. And, rawdataout$postcensor,
which has the same format but with the psotcensoring data
# See vignettes for examples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.