| CTdata | R Documentation |
The results of existing clinical trial data organized as a data file, for use in Vignette 3
data(CTdata)
An object of class data.table (inherits from data.frame) with 56 rows and 7 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.